local _, addon = ...

-- functions
local select, tonumber = select, tonumber
local format, split = string.format, string.split
local C_ChallengeMode = C_ChallengeMode
local C_ChallengeMode_GetMapInfo = C_ChallengeMode.GetMapInfo
local GetBuildInfo = GetBuildInfo
local GetLocale = GetLocale
-- constants
-- frames
-- libs

local isPTR = "7.2.5" == select(1, GetBuildInfo())

addon.shorthandDungeonNames = GetLocale() ~= "enUS" and {} or {
    [197] = "EoA",
    [198] = "DHT",
    [199] = "BRH",
    [200] = "HoV",
    [206] = "Nelth",
    [207] = "Vault",
    [208] = "Maw",
    [209] = "Arcway",
    [210] = "CoS",
    [227] = "Lower Kara",
    [233] = "CoEN",
    [234] = "Upper Kara",
}

function addon:GetMapName(mapId)
    if self.options.useShorthand and self.shorthandDungeonNames[mapId] then
        return self.shorthandDungeonNames[mapId]
    end

    return select(1, C_ChallengeMode_GetMapInfo(mapId))
end

function addon:GetKeystoneInformation(link)
    local info = {split(":", link)}

    local instanceMapId = tonumber(info[2])
    local instanceName = self:GetMapName(instanceMapId)

    local level = tonumber(info[3])

    local isDepleted = 1 ~= tonumber(info[4])
    if isPTR then isDepleted = false end

    return link, instanceMapId, instanceName, level, isDepleted
end

function addon:GetKeystoneDisplayText(link, colour)
    local _, _, instanceName, level, isDepleted = self:GetKeystoneInformation(link)

    if isDepleted then
        if colour then
            return format("|cff%s %s %s|r", "666666", instanceName, level)
        end

        return format("%s %s (depl.)", instanceName, level)
    end

    if colour then
        return format("|cff%s%s|r |cff%s%s|r", "ffffff", instanceName, "00ff00", level)
    end

    return format("%s %s", instanceName, level)
end
